cis_config: /root/cis_interface/cis_interface/cis_interface/interface/PsiInterface.hpp Source File

cis_config

PsiInterface.hpp
1 #include "CisInterface.hpp"
2
4 #ifndef PSIINTERFACE_HPP_
5 #define PSIINTERFACE_HPP_
6
8 #define PsiInput CisInput
9 #define PsiOutput CisOutput
10 #define PsiRpc CisRpc
11 #define PsiRpcServer CisRpcServer
12 #define PsiRpcClient CisRpcClient
13 #define PsiAsciiFileInput CisAsciiFileInput
14 #define PsiAsciiFileOutput CisAsciiFileOutput
15 #define PsiAsciiTableInput CisAsciiTableInput
16 #define PsiAsciiTableOutput CisAsciiTableOutput
17 #define PsiPlyOutput CisPlyOutput
18 #define PsiPlyInput CisPlyInput
19 #define PsiObjOutput CisObjOutput
20 #define PsiObjInput CisObjInput
21
22 #endif /*PSIINTERFACE_HPP_*/